Crate kcr_objectbucket_io

Crate kcr_objectbucket_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the objectbucket.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

objectbucket.io/v1alpha1

  • ObjectBucketClaim
  • ObjectBucket

Modules

v1alpha1